@@ -4,13 +4,12 @@ import (
 	"context"
 	"fmt"
 
-	"github.com/gophercloud/utils/openstack/clientconfig"
 	"github.com/pkg/errors"
 
 	"github.com/openshift/installer/pkg/asset"
-	awsconfig "github.com/openshift/installer/pkg/asset/installconfig/aws"
-	azureconfig "github.com/openshift/installer/pkg/asset/installconfig/azure"
 	gcpconfig "github.com/openshift/installer/pkg/asset/installconfig/gcp"
+	openstackconfig "github.com/openshift/installer/pkg/asset/installconfig/openstack"
+	ovirtconfig "github.com/openshift/installer/pkg/asset/installconfig/ovirt"
 	"github.com/openshift/installer/pkg/types/aws"
 	"github.com/openshift/installer/pkg/types/azure"
 	"github.com/openshift/installer/pkg/types/baremetal"
@@ -18,6 +17,7 @@ import (
 	"github.com/openshift/installer/pkg/types/libvirt"
 	"github.com/openshift/installer/pkg/types/none"
 	"github.com/openshift/installer/pkg/types/openstack"
+	"github.com/openshift/installer/pkg/types/ovirt"
 	"github.com/openshift/installer/pkg/types/vsphere"
 )
 
@@ -45,37 +45,33 @@ func (a *PlatformCredsCheck) Generate(dependencies asset.Parents) error {
 	platform := ic.Config.Platform.Name()
 	switch platform {
 	case aws.Name:
-		permissionGroups := []awsconfig.PermissionGroup{awsconfig.PermissionCreateBase, awsconfig.PermissionDeleteBase}
-		// If subnets are not provided in install-config.yaml, include network permissions
-		if len(ic.Config.AWS.Subnets) == 0 {
-			permissionGroups = append(permissionGroups, awsconfig.PermissionCreateNetworking, awsconfig.PermissionDeleteNetworking)
-		}
-
-		ssn, err := ic.AWS.Session(ctx)
+		_, err := ic.AWS.Session(ctx)
 		if err != nil {
 			return err
 		}
-
-		err = awsconfig.ValidateCreds(ssn, permissionGroups, ic.Config.Platform.AWS.Region)
-		if err != nil {
-			return errors.Wrap(err, "validate AWS credentials")
-		}
 	case gcp.Name:
 		_, err = gcpconfig.GetSession(ctx)
 		if err != nil {
 			return errors.Wrap(err, "creating GCP session")
 		}
 	case openstack.Name:
-		opts := new(clientconfig.ClientOpts)
-		opts.Cloud = ic.Config.Platform.OpenStack.Cloud
-		_, err = clientconfig.GetCloudFromYAML(opts)
+		_, err = openstackconfig.GetSession(ic.Config.Platform.OpenStack.Cloud)
 	case baremetal.Name, libvirt.Name, none.Name, vsphere.Name:
 		// no creds to check
 	case azure.Name:
-		_, err = azureconfig.GetSession()
+		_, err = ic.Azure.Session()
 		if err != nil {
 			return errors.Wrap(err, "creating Azure session")
 		}
+	case ovirt.Name:
+		con, err := ovirtconfig.NewConnection()
+		if err != nil {
+			return errors.Wrap(err, "creating Engine connection")
+		}
+		err = con.Test()
+		if err != nil {
+			return errors.Wrap(err, "testing Engine connection")
+		}
 	default:
 		err = fmt.Errorf("unknown platform type %q", platform)
 	}
